import OCP.TPrsStd
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.Quantity
import OCP.AIS
import OCP.TDataXtd
import OCP.Standard
import OCP.V3d
import OCP.Graphic3d
import OCP.TDF
__all__  = [
"TPrsStd_AISPresentation",
"TPrsStd_AISViewer",
"TPrsStd_Driver",
"TPrsStd_ConstraintDriver",
"TPrsStd_ConstraintTools",
"TPrsStd_AxisDriver",
"TPrsStd_DriverTable",
"TPrsStd_GeometryDriver",
"TPrsStd_NamedShapeDriver",
"TPrsStd_PlaneDriver",
"TPrsStd_PointDriver"
]
class TPrsStd_AISPresentation(OCP.TDF.TDF_Attribute, OCP.Standard.Standard_Transient):
    """
    An attribute to associate an AIS_InteractiveObject to a label in an AIS viewer. This attribute works in collaboration with TPrsStd_AISViewer. Note that all the Set... and Unset... attribute methods as well as the query methods for visualization attributes and the HasOwn... test methods are shortcuts to the respective AIS_InteractiveObject settings.An attribute to associate an AIS_InteractiveObject to a label in an AIS viewer. This attribute works in collaboration with TPrsStd_AISViewer. Note that all the Set... and Unset... attribute methods as well as the query methods for visualization attributes and the HasOwn... test methods are shortcuts to the respective AIS_InteractiveObject settings.An attribute to associate an AIS_InteractiveObject to a label in an AIS viewer. This attribute works in collaboration with TPrsStd_AISViewer. Note that all the Set... and Unset... attribute methods as well as the query methods for visualization attributes and the HasOwn... test methods are shortcuts to the respective AIS_InteractiveObject settings.
    """
    def AddAttribute(self,other : OCP.TDF.TDF_Attribute) -> None: 
        """
        Adds an Attribute <other> to the label of <me>.Raises if there is already one of the same GUID fhan <other>.
        """
    def AddSelectionMode(self,theSelectionMode : int,theTransaction : bool=True) -> None: ...
    def AfterAddition(self) -> None: ...
    def AfterResume(self) -> None: ...
    def AfterRetrieval(self,forceIt : bool=False) -> bool: 
        """
        Something to do AFTER creation of an attribute by persistent-transient translation. The returned status says if AfterUndo has been performed (true) or if this callback must be called once again further (false). If <forceIt> is set to true, the method MUST perform and return true. Does nothing by default and returns true.
        """
    def AfterUndo(self,anAttDelta : OCP.TDF.TDF_AttributeDelta,forceIt : bool=False) -> bool: 
        """
        update AIS viewer according to delta
        """
    def Backup(self) -> None: 
        """
        Backups the attribute. The backuped attribute is flagged "Backuped" and not "Valid".
        """
    def BackupCopy(self) -> OCP.TDF.TDF_Attribute: ...
    def BeforeCommitTransaction(self) -> None: 
        """
        A callback. By default does nothing. It is called by TDF_Data::CommitTransaction() method.
        """
    def BeforeForget(self) -> None: ...
    def BeforeRemoval(self) -> None: ...
    def BeforeUndo(self,anAttDelta : OCP.TDF.TDF_AttributeDelta,forceIt : bool=False) -> bool: ...
    def Color(self) -> OCP.Quantity.Quantity_NameOfColor: ...
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DeltaOnAddition(self) -> OCP.TDF.TDF_DeltaOnAddition: 
        """
        Makes an AttributeDelta because <me> appeared. The only known use of a redefinition of this method is to return a null handle (no delta).
        """
    def DeltaOnForget(self) -> OCP.TDF.TDF_DeltaOnForget: 
        """
        Makes an AttributeDelta because <me> has been forgotten.
        """
    @overload
    def DeltaOnModification(self,anOldAttribute : OCP.TDF.TDF_Attribute) -> OCP.TDF.TDF_DeltaOnModification: 
        """
        Makes a DeltaOnModification between <me> and <anOldAttribute.

        Applies a DeltaOnModification to <me>.
        """
    @overload
    def DeltaOnModification(self,aDelta : OCP.TDF.TDF_DeltaOnModification) -> None: ...
    def DeltaOnRemoval(self) -> OCP.TDF.TDF_DeltaOnRemoval: 
        """
        Makes a DeltaOnRemoval on <me> because <me> has disappeared from the DS.
        """
    def DeltaOnResume(self) -> OCP.TDF.TDF_DeltaOnResume: 
        """
        Makes an AttributeDelta because <me> has been resumed.
        """
    def Display(self,update : bool=False) -> None: 
        """
        Display presentation of object in AIS viewer. If <update> = True then AISObject is recomputed and all the visualization settings are applied
        """
    def Dump(self,anOS : io.BytesIO) -> io.BytesIO: 
        """
        Dumps the minimum information about <me> on <aStream>.
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def Erase(self,remove : bool=False) -> None: 
        """
        Removes the presentation of this AIS presentation attribute from the TPrsStd_AISViewer. If remove is true, this AIS presentation attribute is removed from the interactive context.
        """
    def ExtendedDump(self,anOS : io.BytesIO,aFilter : OCP.TDF.TDF_IDFilter,aMap : OCP.TDF.TDF_AttributeIndexedMap) -> None: 
        """
        Dumps the attribute content on <aStream>, using <aMap> like this: if an attribute is not in the map, first put add it to the map and then dump it. Use the map rank instead of dumping each attribute field.
        """
    def FindAttribute(self,anID : OCP.Standard.Standard_GUID,anAttribute : OCP.TDF.TDF_Attribute) -> bool: 
        """
        Finds an associated attribute of <me>, according to <anID>. the returned <anAttribute> is a valid one. The method returns True if found, False otherwise. A removed attribute cannot be found using this method.
        """
    def Forget(self,aTransaction : int) -> None: 
        """
        Forgets the attribute. <aTransaction> is the current transaction in which the forget is done. A forgotten attribute is also flagged not "Valid".
        """
    def ForgetAllAttributes(self,clearChildren : bool=True) -> None: 
        """
        Forgets all the attributes attached to the label of <me>. Does it on the sub-labels if <clearChildren> is set to true. Of course, this method is compatible with Transaction & Delta mechanisms. Be careful that if <me> will have a null label after this call
        """
    def ForgetAttribute(self,aguid : OCP.Standard.Standard_GUID) -> bool: 
        """
        Forgets the Attribute of GUID <aguid> associated to the label of <me>. Be careful that if <me> is the attribute of <guid>, <me> will have a null label after this call. If the attribute doesn't exist returns False. Otherwise returns True.
        """
    def GetAIS(self) -> OCP.AIS.AIS_InteractiveObject: 
        """
        Returns AIS_InteractiveObject stored in the presentation attribute
        """
    def GetDriverGUID(self) -> OCP.Standard.Standard_GUID: ...
    @staticmethod
    def GetID_s() -> OCP.Standard.Standard_GUID: 
        """
        Returns the GUID for TPrsStd_AISPresentation attributes.
        """
    def GetNbSelectionModes(self) -> int: 
        """
        Returns selection mode(s) of the attribute. It starts with 1 .. GetNbSelectionModes().
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def HasOwnColor(self) -> bool: 
        """
        Returns true if this presentation attribute already has a color setting.
        """
    def HasOwnMaterial(self) -> bool: 
        """
        Returns true if this presentation attribute already has a material setting.
        """
    def HasOwnMode(self) -> bool: ...
    def HasOwnSelectionMode(self) -> bool: ...
    def HasOwnTransparency(self) -> bool: 
        """
        Returns true if this presentation attribute already has a transparency setting.
        """
    def HasOwnWidth(self) -> bool: 
        """
        Returns true if this presentation attribute already has a width setting.
        """
    def ID(self) -> OCP.Standard.Standard_GUID: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsAttribute(self,anID : OCP.Standard.Standard_GUID) -> bool: 
        """
        Returns true if it exists an associated attribute of <me> with <anID> as ID.
        """
    def IsBackuped(self) -> bool: 
        """
        Returns true if the attribute backup status is set. This status is set/unset by the Backup() method.

        Returns true if the attribute backup status is set. This status is set/unset by the Backup() method.
        """
    def IsDisplayed(self) -> bool: 
        """
        Returns true if this AIS presentation attribute is displayed.
        """
    def IsForgotten(self) -> bool: 
        """
        Returns true if the attribute forgotten status is set.

        Returns true if the attribute forgotten status is set.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsNew(self) -> bool: 
        """
        Returns true if the attribute has no backup

        Returns true if the attribute has no backup
        """
    def IsValid(self) -> bool: 
        """
        Returns true if the attribute is valid; i.e. not a backuped or removed one.

        Returns true if the attribute is valid; i.e. not a backuped or removed one.
        """
    def Label(self) -> OCP.TDF.TDF_Label: 
        """
        Returns the label to which the attribute is attached. If the label is not included in a DF, the label is null. See Label. Warning If the label is not included in a data framework, it is null. This function should not be redefined inline.
        """
    def Material(self) -> OCP.Graphic3d.Graphic3d_NameOfMaterial: 
        """
        Returns the material setting for this presentation attribute.
        """
    def Mode(self) -> int: ...
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    def Paste(self,into : OCP.TDF.TDF_Attribute,RT : OCP.TDF.TDF_RelocationTable) -> None: ...
    def References(self,aDataSet : OCP.TDF.TDF_DataSet) -> None: 
        """
        Adds the first level referenced attributes and labels to <aDataSet>.
        """
    def Restore(self,with_ : OCP.TDF.TDF_Attribute) -> None: ...
    def SelectionMode(self,index : int=1) -> int: ...
    def SetColor(self,aColor : OCP.Quantity.Quantity_NameOfColor) -> None: 
        """
        Sets the color aColor for this presentation attribute.
        """
    def SetDisplayed(self,B : bool) -> None: ...
    def SetDriverGUID(self,guid : OCP.Standard.Standard_GUID) -> None: ...
    @overload
    def SetID(self,arg0 : OCP.Standard.Standard_GUID) -> None: 
        """
        Sets specific ID of the attribute (supports several attributes of one type at the same label feature).

        Sets default ID defined in nested class (to be used for attributes having User ID feature).
        """
    @overload
    def SetID(self) -> None: ...
    def SetMaterial(self,aName : OCP.Graphic3d.Graphic3d_NameOfMaterial) -> None: 
        """
        Sets the material aName for this presentation attribute.
        """
    def SetMode(self,theMode : int) -> None: ...
    def SetSelectionMode(self,theSelectionMode : int,theTransaction : bool=True) -> None: 
        """
        Sets selection mode. If "theTransaction" flag is OFF, modification of the attribute doesn't influence the transaction mechanism (the attribute doesn't participate in undo/redo because of this modification). Certainly, if any other data of the attribute is modified (display mode, color, ...), the attribute will be included into undo/redo.
        """
    def SetTransparency(self,aValue : float=0.6) -> None: 
        """
        Sets the transparency value aValue for this presentation attribute. This value is 0.6 by default.
        """
    def SetWidth(self,aWidth : float) -> None: 
        """
        Sets the width aWidth for this presentation attribute.
        """
    @staticmethod
    @overload
    def Set_s(L : OCP.TDF.TDF_Label,driver : OCP.Standard.Standard_GUID) -> TPrsStd_AISPresentation: 
        """
        Creates or retrieves the presentation attribute on the label L, and sets the GUID driver.

        Creates or retrieves the AISPresentation attribute attached to master. The GUID of the driver will be the GUID of master. master is the attribute you want to display.
        """
    @staticmethod
    @overload
    def Set_s(master : OCP.TDF.TDF_Attribute) -> TPrsStd_AISPresentation: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Transaction(self) -> int: 
        """
        Returns the transaction index in which the attribute has been created or modified.

        Returns the transaction index in which the attribute has been created or modified.
        """
    def Transparency(self) -> float: ...
    def UnsetColor(self) -> None: 
        """
        Removes the color setting from this presentation attribute.
        """
    def UnsetMaterial(self) -> None: 
        """
        Removes the material setting from this presentation attribute.
        """
    def UnsetMode(self) -> None: ...
    def UnsetSelectionMode(self) -> None: 
        """
        Clears all selection modes of the attribute.
        """
    def UnsetTransparency(self) -> None: 
        """
        Removes the transparency setting from this presentation attribute.
        """
    def UnsetWidth(self) -> None: 
        """
        Removes the width setting from this presentation attribute.
        """
    @staticmethod
    def Unset_s(L : OCP.TDF.TDF_Label) -> None: ...
    def UntilTransaction(self) -> int: 
        """
        Returns the upper transaction index until which the attribute is/was valid. This number may vary. A removed attribute validity range is reduced to its transaction index.
        """
    def Update(self) -> None: 
        """
        Recompute presentation of object and apply the visualization settings
        """
    def Width(self) -> float: ...
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_AISViewer(OCP.TDF.TDF_Attribute, OCP.Standard.Standard_Transient):
    """
    The groundwork to define an interactive viewer attribute. This attribute stores an interactive context at the root label. You can only have one instance of this class per data framework.The groundwork to define an interactive viewer attribute. This attribute stores an interactive context at the root label. You can only have one instance of this class per data framework.The groundwork to define an interactive viewer attribute. This attribute stores an interactive context at the root label. You can only have one instance of this class per data framework.
    """
    def AddAttribute(self,other : OCP.TDF.TDF_Attribute) -> None: 
        """
        Adds an Attribute <other> to the label of <me>.Raises if there is already one of the same GUID fhan <other>.
        """
    def AfterAddition(self) -> None: 
        """
        Something to do after adding an Attribute to a label.
        """
    def AfterResume(self) -> None: 
        """
        Something to do after resuming an Attribute from a label.
        """
    def AfterRetrieval(self,forceIt : bool=False) -> bool: 
        """
        Something to do AFTER creation of an attribute by persistent-transient translation. The returned status says if AfterUndo has been performed (true) or if this callback must be called once again further (false). If <forceIt> is set to true, the method MUST perform and return true. Does nothing by default and returns true.
        """
    def AfterUndo(self,anAttDelta : OCP.TDF.TDF_AttributeDelta,forceIt : bool=False) -> bool: 
        """
        Something to do after applying <anAttDelta>. The returned status says if AfterUndo has been performed (true) or if this callback must be called once again further (false). If <forceIt> is set to true, the method MUST perform and return true. Does nothing by default and returns true.
        """
    def Backup(self) -> None: 
        """
        Backups the attribute. The backuped attribute is flagged "Backuped" and not "Valid".
        """
    def BackupCopy(self) -> OCP.TDF.TDF_Attribute: 
        """
        Copies the attribute contents into a new other attribute. It is used by Backup().
        """
    def BeforeCommitTransaction(self) -> None: 
        """
        A callback. By default does nothing. It is called by TDF_Data::CommitTransaction() method.
        """
    def BeforeForget(self) -> None: 
        """
        Something to do before forgetting an Attribute to a label.
        """
    def BeforeRemoval(self) -> None: 
        """
        Something to do before removing an Attribute from a label.
        """
    def BeforeUndo(self,anAttDelta : OCP.TDF.TDF_AttributeDelta,forceIt : bool=False) -> bool: 
        """
        Something to do before applying <anAttDelta>. The returned status says if AfterUndo has been performed (true) or if this callback must be called once again further (false). If <forceIt> is set to true, the method MUST perform and return true. Does nothing by default and returns true.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DeltaOnAddition(self) -> OCP.TDF.TDF_DeltaOnAddition: 
        """
        Makes an AttributeDelta because <me> appeared. The only known use of a redefinition of this method is to return a null handle (no delta).
        """
    def DeltaOnForget(self) -> OCP.TDF.TDF_DeltaOnForget: 
        """
        Makes an AttributeDelta because <me> has been forgotten.
        """
    @overload
    def DeltaOnModification(self,anOldAttribute : OCP.TDF.TDF_Attribute) -> OCP.TDF.TDF_DeltaOnModification: 
        """
        Makes a DeltaOnModification between <me> and <anOldAttribute.

        Applies a DeltaOnModification to <me>.
        """
    @overload
    def DeltaOnModification(self,aDelta : OCP.TDF.TDF_DeltaOnModification) -> None: ...
    def DeltaOnRemoval(self) -> OCP.TDF.TDF_DeltaOnRemoval: 
        """
        Makes a DeltaOnRemoval on <me> because <me> has disappeared from the DS.
        """
    def DeltaOnResume(self) -> OCP.TDF.TDF_DeltaOnResume: 
        """
        Makes an AttributeDelta because <me> has been resumed.
        """
    def Dump(self,anOS : io.BytesIO) -> io.BytesIO: 
        """
        Dumps the minimum information about <me> on <aStream>.
        """
    def DumpJson(self,theOStream : io.BytesIO,theDepth : int=-1) -> None: 
        """
        Dumps the content of me into the stream
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def ExtendedDump(self,anOS : io.BytesIO,aFilter : OCP.TDF.TDF_IDFilter,aMap : OCP.TDF.TDF_AttributeIndexedMap) -> None: 
        """
        Dumps the attribute content on <aStream>, using <aMap> like this: if an attribute is not in the map, first put add it to the map and then dump it. Use the map rank instead of dumping each attribute field.
        """
    def FindAttribute(self,anID : OCP.Standard.Standard_GUID,anAttribute : OCP.TDF.TDF_Attribute) -> bool: 
        """
        Finds an associated attribute of <me>, according to <anID>. the returned <anAttribute> is a valid one. The method returns True if found, False otherwise. A removed attribute cannot be found using this method.
        """
    @staticmethod
    @overload
    def Find_s(acces : OCP.TDF.TDF_Label,A : TPrsStd_AISViewer) -> bool: 
        """
        Finds the viewer attribute at the label access, the root of the data framework. Calling this function can be used to initialize an AIS viewer
        """
    @staticmethod
    @overload
    def Find_s(acces : OCP.TDF.TDF_Label,IC : OCP.AIS.AIS_InteractiveContext) -> bool: ...
    @staticmethod
    @overload
    def Find_s(acces : OCP.TDF.TDF_Label,V : OCP.V3d.V3d_Viewer) -> bool: ...
    def Forget(self,aTransaction : int) -> None: 
        """
        Forgets the attribute. <aTransaction> is the current transaction in which the forget is done. A forgotten attribute is also flagged not "Valid".
        """
    def ForgetAllAttributes(self,clearChildren : bool=True) -> None: 
        """
        Forgets all the attributes attached to the label of <me>. Does it on the sub-labels if <clearChildren> is set to true. Of course, this method is compatible with Transaction & Delta mechanisms. Be careful that if <me> will have a null label after this call
        """
    def ForgetAttribute(self,aguid : OCP.Standard.Standard_GUID) -> bool: 
        """
        Forgets the Attribute of GUID <aguid> associated to the label of <me>. Be careful that if <me> is the attribute of <guid>, <me> will have a null label after this call. If the attribute doesn't exist returns False. Otherwise returns True.
        """
    @staticmethod
    def GetID_s() -> OCP.Standard.Standard_GUID: 
        """
        class methods =============
        """
    def GetInteractiveContext(self) -> OCP.AIS.AIS_InteractiveContext: 
        """
        Returns the interactive context in this attribute.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    @staticmethod
    def Has_s(acces : OCP.TDF.TDF_Label) -> bool: 
        """
        returns True if there is an AISViewer attribute in <acces> Data Framework.
        """
    def ID(self) -> OCP.Standard.Standard_GUID: ...
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def IsAttribute(self,anID : OCP.Standard.Standard_GUID) -> bool: 
        """
        Returns true if it exists an associated attribute of <me> with <anID> as ID.
        """
    def IsBackuped(self) -> bool: 
        """
        Returns true if the attribute backup status is set. This status is set/unset by the Backup() method.

        Returns true if the attribute backup status is set. This status is set/unset by the Backup() method.
        """
    def IsForgotten(self) -> bool: 
        """
        Returns true if the attribute forgotten status is set.

        Returns true if the attribute forgotten status is set.
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def IsNew(self) -> bool: 
        """
        Returns true if the attribute has no backup

        Returns true if the attribute has no backup
        """
    def IsValid(self) -> bool: 
        """
        Returns true if the attribute is valid; i.e. not a backuped or removed one.

        Returns true if the attribute is valid; i.e. not a backuped or removed one.
        """
    def Label(self) -> OCP.TDF.TDF_Label: 
        """
        Returns the label to which the attribute is attached. If the label is not included in a DF, the label is null. See Label. Warning If the label is not included in a data framework, it is null. This function should not be redefined inline.
        """
    def NewEmpty(self) -> OCP.TDF.TDF_Attribute: ...
    @staticmethod
    @overload
    def New_s(access : OCP.TDF.TDF_Label,selector : OCP.AIS.AIS_InteractiveContext) -> TPrsStd_AISViewer: 
        """
        create and set an AISViewer at. Raise an exception if Has.

        create and set an AISAttribute at root label. The interactive context is build. Raise an exception if Has.
        """
    @staticmethod
    @overload
    def New_s(acces : OCP.TDF.TDF_Label,viewer : OCP.V3d.V3d_Viewer) -> TPrsStd_AISViewer: ...
    def Paste(self,into : OCP.TDF.TDF_Attribute,RT : OCP.TDF.TDF_RelocationTable) -> None: ...
    def References(self,aDataSet : OCP.TDF.TDF_DataSet) -> None: 
        """
        Adds the first level referenced attributes and labels to <aDataSet>.
        """
    def Restore(self,with_ : OCP.TDF.TDF_Attribute) -> None: ...
    @overload
    def SetID(self,arg0 : OCP.Standard.Standard_GUID) -> None: 
        """
        Sets specific ID of the attribute (supports several attributes of one type at the same label feature).

        Sets default ID defined in nested class (to be used for attributes having User ID feature).
        """
    @overload
    def SetID(self) -> None: ...
    def SetInteractiveContext(self,ctx : OCP.AIS.AIS_InteractiveContext) -> None: 
        """
        Sets the interactive context ctx for this attribute.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Transaction(self) -> int: 
        """
        Returns the transaction index in which the attribute has been created or modified.

        Returns the transaction index in which the attribute has been created or modified.
        """
    def UntilTransaction(self) -> int: 
        """
        Returns the upper transaction index until which the attribute is/was valid. This number may vary. A removed attribute validity range is reduced to its transaction index.
        """
    def Update(self) -> None: 
        """
        Updates the viewer at the label access. access is the root of the data framework.
        """
    @staticmethod
    def Update_s(acces : OCP.TDF.TDF_Label) -> None: 
        """
        AISViewer methods =================
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_Driver(OCP.Standard.Standard_Transient):
    """
    Driver for AIS ============== An abstract class, which - in classes inheriting from it - allows you to update an AIS_InteractiveObject or create one if one does not already exist. For both creation and update, the interactive object is filled with information contained in attributes. These attributes are those found on the label given as an argument in the method Update. true is returned if the interactive object was modified by the update. This class provide an algorithm to Build with its default values (if Null) or Update (if !Null) an AIS_InteractiveObject . Resources are found in attributes associated to a given label.Driver for AIS ============== An abstract class, which - in classes inheriting from it - allows you to update an AIS_InteractiveObject or create one if one does not already exist. For both creation and update, the interactive object is filled with information contained in attributes. These attributes are those found on the label given as an argument in the method Update. true is returned if the interactive object was modified by the update. This class provide an algorithm to Build with its default values (if Null) or Update (if !Null) an AIS_InteractiveObject . Resources are found in attributes associated to a given label.Driver for AIS ============== An abstract class, which - in classes inheriting from it - allows you to update an AIS_InteractiveObject or create one if one does not already exist. For both creation and update, the interactive object is filled with information contained in attributes. These attributes are those found on the label given as an argument in the method Update. true is returned if the interactive object was modified by the update. This class provide an algorithm to Build with its default values (if Null) or Update (if !Null) an AIS_InteractiveObject . Resources are found in attributes associated to a given label.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,L : OCP.TDF.TDF_Label,ais : OCP.AIS.AIS_InteractiveObject) -> bool: 
        """
        Updates the interactive object ais with information found on the attributes associated with the label L.
        """
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_ConstraintDriver(TPrsStd_Driver, OCP.Standard.Standard_Transient):
    """
    An implementation of TPrsStd_Driver for constraints.An implementation of TPrsStd_Driver for constraints.An implementation of TPrsStd_Driver for constraints.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,aLabel : OCP.TDF.TDF_Label,anAISObject : OCP.AIS.AIS_InteractiveObject) -> bool: 
        """
        Build the AISObject (if null) or update it. No compute is done. Returns <True> if information was found and AISObject updated.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_ConstraintTools():
    @staticmethod
    def ComputeAngleForOneFace_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeAngle_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeCoincident_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeConcentric_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeDiameter_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeDistance_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeEqualDistance_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeEqualRadius_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeFix_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeMaxRadius_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeMidPoint_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeMinRadius_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeOffset_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeOthers_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeParallel_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputePerpendicular_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputePlacement_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeRadius_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeRound_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeSymmetry_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeTangent_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    @staticmethod
    def ComputeTextAndValue_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,aText : OCP.TCollection.TCollection_ExtendedString,anIsAngle : bool) -> tuple[float]: ...
    @staticmethod
    def UpdateOnlyValue_s(aConst : OCP.TDataXtd.TDataXtd_Constraint,anAIS : OCP.AIS.AIS_InteractiveObject) -> None: ...
    def __init__(self) -> None: ...
    pass
class TPrsStd_AxisDriver(TPrsStd_Driver, OCP.Standard.Standard_Transient):
    """
    An implementation of TPrsStd_Driver for axes.An implementation of TPrsStd_Driver for axes.An implementation of TPrsStd_Driver for axes.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,aLabel : OCP.TDF.TDF_Label,anAISObject : OCP.AIS.AIS_InteractiveObject) -> bool: 
        """
        Build the AISObject (if null) or update it. No compute is done. Returns <True> if information was found and AISObject updated.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_DriverTable(OCP.Standard.Standard_Transient):
    """
    This class is a container to record (AddDriver) binding between GUID and TPrsStd_Driver. You create a new instance of TPrsStd_Driver and use the method AddDriver to load it into the driver table. the methodThis class is a container to record (AddDriver) binding between GUID and TPrsStd_Driver. You create a new instance of TPrsStd_Driver and use the method AddDriver to load it into the driver table. the methodThis class is a container to record (AddDriver) binding between GUID and TPrsStd_Driver. You create a new instance of TPrsStd_Driver and use the method AddDriver to load it into the driver table. the method
    """
    def AddDriver(self,guid : OCP.Standard.Standard_GUID,driver : TPrsStd_Driver) -> bool: 
        """
        Returns true if the driver has been added successfully to the driver table.
        """
    def Clear(self) -> None: 
        """
        Removes all drivers. Returns true if the driver has been removed successfully. If this method is used, the InitStandardDrivers method should be called to fill the table with standard drivers.
        """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def FindDriver(self,guid : OCP.Standard.Standard_GUID,driver : TPrsStd_Driver) -> bool: 
        """
        Returns true if the driver was found.
        """
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    @staticmethod
    def Get_s() -> TPrsStd_DriverTable: 
        """
        Returns the static table. If it does not exist, creates it and fills it with standard drivers.
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    def InitStandardDrivers(self) -> None: 
        """
        Fills the table with standard drivers
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def RemoveDriver(self,guid : OCP.Standard.Standard_GUID) -> bool: 
        """
        Removes a driver with the given GUID. Returns true if the driver has been removed successfully.
        """
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_GeometryDriver(TPrsStd_Driver, OCP.Standard.Standard_Transient):
    """
    This method is an implementation of TPrsStd_Driver for geometries.This method is an implementation of TPrsStd_Driver for geometries.This method is an implementation of TPrsStd_Driver for geometries.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,aLabel : OCP.TDF.TDF_Label,anAISObject : OCP.AIS.AIS_InteractiveObject) -> bool: 
        """
        Build the AISObject (if null) or update it. No compute is done. Returns <True> if information was found and AISObject updated.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_NamedShapeDriver(TPrsStd_Driver, OCP.Standard.Standard_Transient):
    """
    An implementation of TPrsStd_Driver for named shapes.An implementation of TPrsStd_Driver for named shapes.An implementation of TPrsStd_Driver for named shapes.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,aLabel : OCP.TDF.TDF_Label,anAISObject : OCP.AIS.AIS_InteractiveObject) -> bool: 
        """
        Build the AISObject (if null) or update it. No compute is done. Returns <True> if information was found and AISObject updated.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_PlaneDriver(TPrsStd_Driver, OCP.Standard.Standard_Transient):
    """
    An implementation of TPrsStd_Driver for planes.An implementation of TPrsStd_Driver for planes.An implementation of TPrsStd_Driver for planes.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,aLabel : OCP.TDF.TDF_Label,anAISObject : OCP.AIS.AIS_InteractiveObject) -> bool: 
        """
        Build the AISObject (if null) or update it. No compute is done. Returns <True> if information was found and AISObject updated.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass
class TPrsStd_PointDriver(TPrsStd_Driver, OCP.Standard.Standard_Transient):
    """
    An implementation of TPrsStd_Driver for points.An implementation of TPrsStd_Driver for points.An implementation of TPrsStd_Driver for points.
    """
    def DecrementRefCounter(self) -> int: 
        """
        Decrements the reference counter of this object; returns the decremented value
        """
    def Delete(self) -> None: 
        """
        Memory deallocator for transient classes
        """
    def DynamicType(self) -> OCP.Standard.Standard_Type: ...
    def GetRefCount(self) -> int: 
        """
        Get the reference counter of this object
        """
    def IncrementRefCounter(self) -> None: 
        """
        Increments the reference counter of this object
        """
    @overload
    def IsInstance(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns a true value if this is an instance of Type.

        Returns a true value if this is an instance of TypeName.
        """
    @overload
    def IsInstance(self,theTypeName : str) -> bool: ...
    @overload
    def IsKind(self,theType : OCP.Standard.Standard_Type) -> bool: 
        """
        Returns true if this is an instance of Type or an instance of any class that inherits from Type. Note that multiple inheritance is not supported by OCCT RTTI mechanism.

        Returns true if this is an instance of TypeName or an instance of any class that inherits from TypeName. Note that multiple inheritance is not supported by OCCT RTTI mechanism.
        """
    @overload
    def IsKind(self,theTypeName : str) -> bool: ...
    def This(self) -> OCP.Standard.Standard_Transient: 
        """
        Returns non-const pointer to this object (like const_cast). For protection against creating handle to objects allocated in stack or call from constructor, it will raise exception Standard_ProgramError if reference counter is zero.
        """
    def Update(self,aLabel : OCP.TDF.TDF_Label,anAISObject : OCP.AIS.AIS_InteractiveObject) -> bool: 
        """
        Build the AISObject (if null) or update it. No compute is done. Returns <True> if information was found and AISObject updated.
        """
    def __init__(self) -> None: ...
    @staticmethod
    def get_type_descriptor_s() -> OCP.Standard.Standard_Type: ...
    @staticmethod
    def get_type_name_s() -> str: ...
    pass



import OCP.IGESCAFControl
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.TCollection
import io
import OCP.Quantity
import OCP.Resource
import OCP.TColStd
import OCP.XSControl
import OCP.TopoDS
import OCP.TDocStd
import OCP.Interface
import OCP.IFSelect
import OCP.IGESControl
import OCP.Standard
import OCP.DE
import OCP.TDF
import OCP.IGESData
import OCP.Transfer
__all__  = [
"IGESCAFControl",
"IGESCAFControl_Reader",
"IGESCAFControl_Writer"
]
class IGESCAFControl():
    """
    Provides high-level API to translate IGES file to and from DECAF document
    """
    @staticmethod
    def DecodeColor_s(col : int) -> OCP.Quantity.Quantity_Color: 
        """
        Provides a tool for writing IGES file Converts IGES color index to CASCADE color
        """
    @staticmethod
    def EncodeColor_s(col : OCP.Quantity.Quantity_Color) -> int: 
        """
        Tries to Convert CASCADE color to IGES color index If no corresponding color defined in IGES, returns 0
        """
    def __init__(self) -> None: ...
    pass
class IGESCAFControl_Reader(OCP.IGESControl.IGESControl_Reader, OCP.XSControl.XSControl_Reader):
    """
    Provides a tool to read IGES file and put it into DECAF document. Besides transfer of shapes (including assemblies) provided by IGESControl, supports also colors and part names IGESCAFControl_Reader reader; Methods for translation of an IGES file: reader.ReadFile("filename"); reader.Transfer(Document); or reader.Perform("filename",doc); Methods for managing reading attributes. Colors reader.SetColorMode(colormode); Standard_Boolean colormode = reader.GetColorMode(); Layers reader.SetLayerMode(layermode); Standard_Boolean layermode = reader.GetLayerMode(); Names reader.SetNameMode(namemode); Standard_Boolean namemode = reader.GetNameMode();
    """
    def ClearShapes(self) -> None: 
        """
        Clears the list of shapes that may have accumulated in calls to TransferOne or TransferRoot.C
        """
    def GetColorMode(self) -> bool: ...
    def GetLayerMode(self) -> bool: ...
    def GetNameMode(self) -> bool: ...
    def GetReadVisible(self) -> bool: ...
    def GetShapeFixParameters(self) -> OCP.Resource.Resource_DataMapOfAsciiStringAsciiString: 
        """
        Returns parameters for shape processing that was set by SetParameters() method.
        """
    def GetShapeProcessFlags(self) -> Any: 
        """
        Returns flags defining operations to be performed on shapes.
        """
    def GetStatsTransfer(self,list : OCP.TColStd.TColStd_HSequenceOfTransient) -> tuple[int, int, int]: 
        """
        Gives statistics about Transfer
        """
    @overload
    def GiveList(self,first : str='',second : str='') -> OCP.TColStd.TColStd_HSequenceOfTransient: 
        """
        Returns a list of entities from the IGES or STEP file according to the following rules: - if first and second are empty strings, the whole file is selected. - if first is an entity number or label, the entity referred to is selected. - if first is a list of entity numbers/labels separated by commas, the entities referred to are selected, - if first is the name of a selection in the worksession and second is not defined, the list contains the standard output for that selection. - if first is the name of a selection and second is defined, the criterion defined by second is applied to the result of the first selection. A selection is an operator which computes a list of entities from a list given in input according to its type. If no list is specified, the selection computes its list of entities from the whole model. A selection can be: - A predefined selection (xst-transferrable-mode) - A filter based on a signature A Signature is an operator which returns a string from an entity according to its type. For example: - "xst-type" (CDL) - "iges-level" - "step-type". For example, if you wanted to select only the advanced_faces in a STEP file you would use the following code: Example Reader.GiveList("xst-transferrable-roots","step-type(ADVANCED_FACE)"); Warning If the value given to second is incorrect, it will simply be ignored.

        Computes a List of entities from the model as follows <first> being a Selection, <ent> being an entity or a list of entities (as a HSequenceOfTransient) : the standard result of this selection applied to this list if <first> is erroneous, a null handle is returned
        """
    @overload
    def GiveList(self,first : str,ent : OCP.Standard.Standard_Transient) -> OCP.TColStd.TColStd_HSequenceOfTransient: ...
    def IGESModel(self) -> OCP.IGESData.IGESData_IGESModel: 
        """
        Returns the model as a IGESModel. It can then be consulted (header, product)
        """
    def Model(self) -> OCP.Interface.Interface_InterfaceModel: 
        """
        Returns the model. It can then be consulted (header, product)
        """
    def NbRootsForTransfer(self) -> int: 
        """
        Determines the list of root entities from Model which are candidate for a transfer to a Shape (type of entities is PRODUCT) <theReadOnlyVisible> is taken into account to define roots
        """
    def NbShapes(self) -> int: 
        """
        Returns the number of shapes produced by translation.
        """
    def OneShape(self) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns all of the results in a single shape which is: - a null shape if there are no results, - a shape if there is one result, - a compound containing the resulting shapes if there are more than one.
        """
    @overload
    def Perform(self,theFileName : OCP.TCollection.TCollection_AsciiString,theDoc : OCP.TDocStd.TDocStd_Document,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Translate IGES file given by filename into the document Return True if succeeded, and False in case of fail
        """
    @overload
    def Perform(self,theFileName : str,theDoc : OCP.TDocStd.TDocStd_Document,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: ...
    @overload
    def PrintCheckLoad(self,failsonly : bool,mode : OCP.IFSelect.IFSelect_PrintCount) -> None: 
        """
        Prints the check list attached to loaded data, on the Standard Trace File (starts at std::cout) All messages or fails only, according to <failsonly> mode = 0 : per entity, prints messages mode = 1 : per message, just gives count of entities per check mode = 2 : also gives entity numbers

        Prints the check list attached to loaded data.
        """
    @overload
    def PrintCheckLoad(self,theStream : io.BytesIO,failsonly : bool,mode : OCP.IFSelect.IFSelect_PrintCount) -> None: ...
    @overload
    def PrintCheckTransfer(self,failsonly : bool,mode : OCP.IFSelect.IFSelect_PrintCount) -> None: 
        """
        Displays check results for the last translation of IGES or STEP entities to Open CASCADE entities. Only fail messages are displayed if failsonly is true. All messages are displayed if failsonly is false. mode determines the contents and the order of the messages according to the terms of the IFSelect_PrintCount enumeration.

        Displays check results for the last translation of IGES or STEP entities to Open CASCADE entities.
        """
    @overload
    def PrintCheckTransfer(self,theStream : io.BytesIO,failsonly : bool,mode : OCP.IFSelect.IFSelect_PrintCount) -> None: ...
    @overload
    def PrintStatsTransfer(self,what : int,mode : int=0) -> None: 
        """
        Displays the statistics for the last translation. what defines the kind of statistics that are displayed as follows: - 0 gives general statistics (number of translated roots, number of warnings, number of fail messages), - 1 gives root results, - 2 gives statistics for all checked entities, - 3 gives the list of translated entities, - 4 gives warning and fail messages, - 5 gives fail messages only. The use of mode depends on the value of what. If what is 0, mode is ignored. If what is 1, 2 or 3, mode defines the following: - 0 lists the numbers of IGES or STEP entities in the respective model - 1 gives the number, identifier, type and result type for each IGES or STEP entity and/or its status (fail, warning, etc.) - 2 gives maximum information for each IGES or STEP entity (i.e. checks) - 3 gives the number of entities per type of IGES or STEP entity - 4 gives the number of IGES or STEP entities per result type and/or status - 5 gives the number of pairs (IGES or STEP or result type and status) - 6 gives the number of pairs (IGES or STEP or result type and status) AND the list of entity numbers in the IGES or STEP model. If what is 4 or 5, mode defines the warning and fail messages as follows: - if mode is 0 all warnings and checks per entity are returned - if mode is 2 the list of entities per warning is returned. If mode is not set, only the list of all entities per warning is given.

        Displays the statistics for the last translation.
        """
    @overload
    def PrintStatsTransfer(self,theStream : io.BytesIO,what : int,mode : int=0) -> None: ...
    def PrintTransferInfo(self,failwarn : OCP.IFSelect.IFSelect_PrintFail,mode : OCP.IFSelect.IFSelect_PrintCount) -> None: 
        """
        Prints Statistics and check list for Transfer
        """
    def ReadFile(self,filename : str) -> OCP.IFSelect.IFSelect_ReturnStatus: 
        """
        Loads a file and returns the read status Zero for a Model which complies with the Controller
        """
    def ReadStream(self,theName : str,theIStream : io.BytesIO) -> OCP.IFSelect.IFSelect_ReturnStatus: 
        """
        Loads a file from stream and returns the read status
        """
    def RootForTransfer(self,num : int=1) -> OCP.Standard.Standard_Transient: 
        """
        Returns an IGES or STEP root entity for translation. The entity is identified by its rank in a list.
        """
    def SetColorMode(self,theMode : bool) -> None: 
        """
        Set ColorMode for indicate read Colors or not.
        """
    def SetLayerMode(self,theMode : bool) -> None: 
        """
        Set LayerMode for indicate read Layers or not.
        """
    def SetNameMode(self,theMode : bool) -> None: 
        """
        Set NameMode for indicate read Name or not.
        """
    def SetNorm(self,norm : str) -> bool: 
        """
        Sets a specific norm to <me> Returns True if done, False if <norm> is not available
        """
    def SetReadVisible(self,ReadRoot : bool) -> None: 
        """
        Set the transion of ALL Roots (if theReadOnlyVisible is False) or of Visible Roots (if theReadOnlyVisible is True)

        Set the transion of ALL Roots (if theReadOnlyVisible is False) or of Visible Roots (if theReadOnlyVisible is True)
        """
    @overload
    def SetShapeFixParameters(self,theParameters : OCP.Resource.Resource_DataMapOfAsciiStringAsciiString) -> None: 
        """
        Sets parameters for shape processing.

        Sets parameters for shape processing. Parameters from theParameters are copied to the internal map. Parameters from theAdditionalParameters are copied to the internal map if they are not present in theParameters.
        """
    @overload
    def SetShapeFixParameters(self,theParameters : OCP.DE.DE_ShapeFixParameters,theAdditionalParameters : OCP.Resource.Resource_DataMapOfAsciiStringAsciiString=OCP.Resource.Resource_DataMapOfAsciiStringAsciiString) -> None: ...
    def SetShapeProcessFlags(self,theFlags : Any) -> None: 
        """
        Sets flags defining operations to be performed on shapes.
        """
    def SetWS(self,WS : OCP.XSControl.XSControl_WorkSession,scratch : bool=True) -> None: 
        """
        Sets a specific session to <me>
        """
    def Shape(self,num : int=1) -> OCP.TopoDS.TopoDS_Shape: 
        """
        Returns the shape resulting from a translation and identified by the rank num. num equals 1 by default. In other words, the first shape resulting from the translation is returned.
        """
    def Transfer(self,theDoc : OCP.TDocStd.TDocStd_Document,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Translates currently loaded IGES file into the document Returns True if succeeded, and False in case of fail
        """
    def TransferEntity(self,start : OCP.Standard.Standard_Transient,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Translates an IGES or STEP entity in the model. true is returned if a shape is produced; otherwise, false is returned.
        """
    def TransferList(self,list : OCP.TColStd.TColStd_HSequenceOfTransient,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> int: 
        """
        Translates a list of entities. Returns the number of IGES or STEP entities that were successfully translated. The list can be produced with GiveList. Warning - This function does not clear the existing output shapes.
        """
    def TransferOne(self,num : int,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Translates an IGES or STEP entity identified by the rank num in the model. false is returned if no shape is produced.
        """
    def TransferOneRoot(self,num : int=1,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Translates a root identified by the rank num in the model. false is returned if no shape is produced.
        """
    def TransferRoots(self,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> int: 
        """
        Translates all translatable roots and returns the number of successful translations. Warning - This function clears existing output shapes first.
        """
    def WS(self) -> OCP.XSControl.XSControl_WorkSession: 
        """
        Returns the session used in <me>
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theWS : OCP.XSControl.XSControl_WorkSession,FromScratch : bool=True) -> None: ...
    pass
class IGESCAFControl_Writer(OCP.IGESControl.IGESControl_Writer):
    """
    Provides a tool to write DECAF document to the IGES file. Besides transfer of shapes (including assemblies) provided by IGESControl, supports also colors and part names IGESCAFControl_Writer writer(); Methods for writing IGES file: writer.Transfer (Document); writer.Write("filename") or writer.Write(OStream) or writer.Perform(Document,"filename"); Methods for managing the writing of attributes. Colors writer.SetColorMode(colormode); Standard_Boolean colormode = writer.GetColorMode(); Layers writer.SetLayerMode(layermode); Standard_Boolean layermode = writer.GetLayerMode(); Names writer.SetNameMode(namemode); Standard_Boolean namemode = writer.GetNameMode();
    """
    def AddEntity(self,ent : OCP.IGESData.IGESData_IGESEntity) -> bool: 
        """
        Adds an IGES entity (and the ones it references) to the model
        """
    def AddGeom(self,geom : OCP.Standard.Standard_Transient) -> bool: 
        """
        Translates a Geometry (Surface or Curve) to IGES Entities and adds them to the model Returns True if done, False if geom is neither a Surface or a Curve suitable for IGES or is null
        """
    def AddShape(self,sh : OCP.TopoDS.TopoDS_Shape,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Translates a Shape to IGES Entities and adds them to the model Returns True if done, False if Shape not suitable for IGES or null
        """
    def ComputeModel(self) -> None: 
        """
        Computes the entities found in the model, which is ready to be written. This contrasts with the default computation of headers only.
        """
    def GetColorMode(self) -> bool: ...
    def GetLayerMode(self) -> bool: ...
    def GetNameMode(self) -> bool: ...
    def GetShapeFixParameters(self) -> OCP.Resource.Resource_DataMapOfAsciiStringAsciiString: 
        """
        Returns parameters for shape processing that was set by SetParameters() method.
        """
    def GetShapeProcessFlags(self) -> Any: 
        """
        Returns flags defining operations to be performed on shapes.
        """
    def Model(self) -> OCP.IGESData.IGESData_IGESModel: 
        """
        Returns the IGES model to be written in output.
        """
    @overload
    def Perform(self,doc : OCP.TDocStd.TDocStd_Document,filename : OCP.TCollection.TCollection_AsciiString,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Transfers a document and writes it to a IGES file Returns True if translation is OK
        """
    @overload
    def Perform(self,doc : OCP.TDocStd.TDocStd_Document,filename : str,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: ...
    def SetColorMode(self,colormode : bool) -> None: 
        """
        Set ColorMode for indicate write Colors or not.
        """
    def SetLayerMode(self,layermode : bool) -> None: 
        """
        Set LayerMode for indicate write Layers or not.
        """
    def SetNameMode(self,namemode : bool) -> None: 
        """
        Set NameMode for indicate write Name or not.
        """
    @overload
    def SetShapeFixParameters(self,theParameters : OCP.Resource.Resource_DataMapOfAsciiStringAsciiString) -> None: 
        """
        Sets parameters for shape processing.

        Sets parameters for shape processing. Parameters from theParameters are copied to the internal map. Parameters from theAdditionalParameters are copied to the internal map if they are not present in theParameters.
        """
    @overload
    def SetShapeFixParameters(self,theParameters : OCP.DE.DE_ShapeFixParameters,theAdditionalParameters : OCP.Resource.Resource_DataMapOfAsciiStringAsciiString=OCP.Resource.Resource_DataMapOfAsciiStringAsciiString) -> None: ...
    def SetShapeProcessFlags(self,theFlags : Any) -> None: 
        """
        Sets flags defining operations to be performed on shapes.
        """
    def SetTransferProcess(self,TP : OCP.Transfer.Transfer_FinderProcess) -> None: 
        """
        Returns/Sets the TransferProcess : it contains final results and if some, check messages
        """
    @overload
    def Transfer(self,doc : OCP.TDocStd.TDocStd_Document,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: 
        """
        Transfers a document to a IGES model Returns True if translation is OK

        Transfers labels to a IGES model Returns True if translation is OK

        Transfers label to a IGES model Returns True if translation is OK
        """
    @overload
    def Transfer(self,labels : OCP.TDF.TDF_LabelSequence,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: ...
    @overload
    def Transfer(self,label : OCP.TDF.TDF_Label,theProgress : OCP.Message.Message_ProgressRange=OCP.Message.Message_ProgressRange) -> bool: ...
    def TransferProcess(self) -> OCP.Transfer.Transfer_FinderProcess: ...
    @overload
    def Write(self,S : io.BytesIO,fnes : bool=False) -> bool: 
        """
        Computes then writes the model to an OStream Returns True when done, false in case of error

        Prepares and writes an IGES model either to an OStream, S or to a file name,CString. Returns True if the operation was performed correctly and False if an error occurred (for instance, if the processor could not create the file).
        """
    @overload
    def Write(self,file : str,fnes : bool=False) -> bool: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,WS : OCP.XSControl.XSControl_WorkSession,scratch : bool=True) -> None: ...
    @overload
    def __init__(self,theWS : OCP.XSControl.XSControl_WorkSession,theUnit : str) -> None: ...
    pass



import OCP.HatchGen
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.IntRes2d
import OCP.TopAbs
import OCP.NCollection
__all__  = [
"HatchGen_Domain",
"HatchGen_Domains",
"HatchGen_ErrorStatus",
"HatchGen_IntersectionPoint",
"HatchGen_IntersectionType",
"HatchGen_PointOnElement",
"HatchGen_PointOnHatching",
"HatchGen_PointsOnElement",
"HatchGen_PointsOnHatching",
"HatchGen_IncoherentParity",
"HatchGen_IncompatibleStates",
"HatchGen_NoProblem",
"HatchGen_TANGENT",
"HatchGen_TOUCH",
"HatchGen_TRUE",
"HatchGen_TransitionFailure",
"HatchGen_TrimFailure",
"HatchGen_UNDETERMINED"
]
class HatchGen_Domain():
    def Dump(self,Index : int=0) -> None: 
        """
        Dump of the domain.
        """
    def FirstPoint(self) -> HatchGen_PointOnHatching: 
        """
        Returns the first point of the domain. The exception DomainError is raised if HasFirstPoint returns False.

        Returns the first point of the domain. The exception DomainError is raised if HasFirstPoint returns False.
        """
    def HasFirstPoint(self) -> bool: 
        """
        Returns True if the domain has a first point.

        Returns True if the domain has a first point.
        """
    def HasSecondPoint(self) -> bool: 
        """
        Returns True if the domain has a second point.

        Returns True if the domain has a second point.
        """
    def SecondPoint(self) -> HatchGen_PointOnHatching: 
        """
        Returns the second point of the domain. The exception DomainError is raised if HasSecondPoint returns False.

        Returns the second point of the domain. The exception DomainError is raised if HasSecondPoint returns False.
        """
    @overload
    def SetFirstPoint(self,P : HatchGen_PointOnHatching) -> None: 
        """
        Sets the first point of the domain.

        Sets the first point of the domain at the infinite.

        Sets the first point of the domain.

        Sets the first point of the domain at the infinite.
        """
    @overload
    def SetFirstPoint(self) -> None: ...
    @overload
    def SetPoints(self,P1 : HatchGen_PointOnHatching,P2 : HatchGen_PointOnHatching) -> None: 
        """
        Sets the first and the second points of the domain.

        Sets the first and the second points of the domain as the infinite.

        Sets the first and the second points of the domain.

        Sets the first and the second points of the domain as the infinite.
        """
    @overload
    def SetPoints(self) -> None: ...
    @overload
    def SetSecondPoint(self,P : HatchGen_PointOnHatching) -> None: 
        """
        Sets the second point of the domain.

        Sets the second point of the domain at the infinite.

        Sets the second point of the domain.

        Sets the second point of the domain at the infinite.
        """
    @overload
    def SetSecondPoint(self) -> None: ...
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,P1 : HatchGen_PointOnHatching,P2 : HatchGen_PointOnHatching) -> None: ...
    @overload
    def __init__(self,P : HatchGen_PointOnHatching,First : bool) -> None: ...
    pass
class HatchGen_Domains(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : HatchGen_Domain) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : HatchGen_Domains) -> None: ...
    def Assign(self,theOther : HatchGen_Domains) -> HatchGen_Domains: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> HatchGen_Domain: 
        """
        First item access
        """
    def ChangeLast(self) -> HatchGen_Domain: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> HatchGen_Domain: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> HatchGen_Domain: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : HatchGen_Domains) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : HatchGen_Domain) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : HatchGen_Domain) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : HatchGen_Domains) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> HatchGen_Domain: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : HatchGen_Domain) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : HatchGen_Domains) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : HatchGen_Domain) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : HatchGen_Domains) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> HatchGen_Domain: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HatchGen_Domain: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : HatchGen_Domains) -> None: ...
    def __iter__(self) -> Iterator[HatchGen_Domain]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class HatchGen_ErrorStatus():
    """
    Error status.

    Members:

      HatchGen_NoProblem

      HatchGen_TrimFailure

      HatchGen_TransitionFailure

      HatchGen_IncoherentParity

      HatchGen_IncompatibleStates
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    HatchGen_IncoherentParity: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_IncoherentParity: 3>
    HatchGen_IncompatibleStates: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_IncompatibleStates: 4>
    HatchGen_NoProblem: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_NoProblem: 0>
    HatchGen_TransitionFailure: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_TransitionFailure: 2>
    HatchGen_TrimFailure: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_TrimFailure: 1>
    __entries: dict # value = {'HatchGen_NoProblem': (<HatchGen_ErrorStatus.HatchGen_NoProblem: 0>, None), 'HatchGen_TrimFailure': (<HatchGen_ErrorStatus.HatchGen_TrimFailure: 1>, None), 'HatchGen_TransitionFailure': (<HatchGen_ErrorStatus.HatchGen_TransitionFailure: 2>, None), 'HatchGen_IncoherentParity': (<HatchGen_ErrorStatus.HatchGen_IncoherentParity: 3>, None), 'HatchGen_IncompatibleStates': (<HatchGen_ErrorStatus.HatchGen_IncompatibleStates: 4>, None)}
    __members__: dict # value = {'HatchGen_NoProblem': <HatchGen_ErrorStatus.HatchGen_NoProblem: 0>, 'HatchGen_TrimFailure': <HatchGen_ErrorStatus.HatchGen_TrimFailure: 1>, 'HatchGen_TransitionFailure': <HatchGen_ErrorStatus.HatchGen_TransitionFailure: 2>, 'HatchGen_IncoherentParity': <HatchGen_ErrorStatus.HatchGen_IncoherentParity: 3>, 'HatchGen_IncompatibleStates': <HatchGen_ErrorStatus.HatchGen_IncompatibleStates: 4>}
    pass
class HatchGen_IntersectionPoint():
    def Dump(self,Index : int=0) -> None: 
        """
        Dump of the point on element.
        """
    def Index(self) -> int: 
        """
        Returns the index of the supporting curve.
        """
    def Parameter(self) -> float: 
        """
        Returns the parameter on the curve.
        """
    def Position(self) -> OCP.TopAbs.TopAbs_Orientation: 
        """
        Returns the position of the point on the curve.
        """
    def SegmentBeginning(self) -> bool: 
        """
        Returns the flag that the point is the beginning of a segment.
        """
    def SegmentEnd(self) -> bool: 
        """
        Returns the flag that the point is the end of a segment.
        """
    def SetIndex(self,Index : int) -> None: 
        """
        Sets the index of the supporting curve.
        """
    def SetParameter(self,Parameter : float) -> None: 
        """
        Sets the parameter on the curve.
        """
    def SetPosition(self,Position : OCP.TopAbs.TopAbs_Orientation) -> None: 
        """
        Sets the position of the point on the curve.
        """
    def SetSegmentBeginning(self,State : bool=True) -> None: 
        """
        Sets the flag that the point is the beginning of a segment.
        """
    def SetSegmentEnd(self,State : bool=True) -> None: 
        """
        Sets the flag that the point is the end of a segment.
        """
    def SetStateAfter(self,State : OCP.TopAbs.TopAbs_State) -> None: 
        """
        Sets the transition state after the intersection.
        """
    def SetStateBefore(self,State : OCP.TopAbs.TopAbs_State) -> None: 
        """
        Sets the transition state before the intersection.
        """
    def StateAfter(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the transition state after of the intersection.
        """
    def StateBefore(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the transition state before the intersection.
        """
    pass
class HatchGen_IntersectionType():
    """
    Intersection type between the hatching and the element.

    Members:

      HatchGen_TRUE

      HatchGen_TOUCH

      HatchGen_TANGENT

      HatchGen_UNDETERMINED
    """
    def __eq__(self,other : object) -> bool: ...
    def __getstate__(self) -> int: ...
    def __hash__(self) -> int: ...
    def __index__(self) -> int: ...
    def __init__(self,value : int) -> None: ...
    def __int__(self) -> int: ...
    def __ne__(self,other : object) -> bool: ...
    def __repr__(self) -> str: ...
    def __setstate__(self,state : int) -> None: ...
    def __str__(self) -> str: ...
    @property
    def name(self) -> None:
        """
        :type: None
        """
    @property
    def value(self) -> int:
        """
        :type: int
        """
    HatchGen_TANGENT: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_TANGENT: 2>
    HatchGen_TOUCH: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_TOUCH: 1>
    HatchGen_TRUE: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_TRUE: 0>
    HatchGen_UNDETERMINED: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_UNDETERMINED: 3>
    __entries: dict # value = {'HatchGen_TRUE': (<HatchGen_IntersectionType.HatchGen_TRUE: 0>, None), 'HatchGen_TOUCH': (<HatchGen_IntersectionType.HatchGen_TOUCH: 1>, None), 'HatchGen_TANGENT': (<HatchGen_IntersectionType.HatchGen_TANGENT: 2>, None), 'HatchGen_UNDETERMINED': (<HatchGen_IntersectionType.HatchGen_UNDETERMINED: 3>, None)}
    __members__: dict # value = {'HatchGen_TRUE': <HatchGen_IntersectionType.HatchGen_TRUE: 0>, 'HatchGen_TOUCH': <HatchGen_IntersectionType.HatchGen_TOUCH: 1>, 'HatchGen_TANGENT': <HatchGen_IntersectionType.HatchGen_TANGENT: 2>, 'HatchGen_UNDETERMINED': <HatchGen_IntersectionType.HatchGen_UNDETERMINED: 3>}
    pass
class HatchGen_PointOnElement(HatchGen_IntersectionPoint):
    def Dump(self,Index : int=0) -> None: 
        """
        Dump of the point on element.
        """
    def Index(self) -> int: 
        """
        Returns the index of the supporting curve.
        """
    def IntersectionType(self) -> HatchGen_IntersectionType: 
        """
        Returns the intersection type at this point.

        Returns the intersection type at this point.
        """
    def IsDifferent(self,Point : HatchGen_PointOnElement,Confusion : float) -> bool: 
        """
        Tests if the point is different from an other.
        """
    def IsIdentical(self,Point : HatchGen_PointOnElement,Confusion : float) -> bool: 
        """
        Tests if the point is identical to an other. That is to say : P1.myIndex = P2.myIndex Abs (P1.myParam - P2.myParam) <= Confusion P1.myPosit = P2.myPosit P1.myBefore = P2.myBefore P1.myAfter = P2.myAfter P1.mySegBeg = P2.mySegBeg P1.mySegEnd = P2.mySegEnd P1.myType = P2.myType
        """
    def Parameter(self) -> float: 
        """
        Returns the parameter on the curve.
        """
    def Position(self) -> OCP.TopAbs.TopAbs_Orientation: 
        """
        Returns the position of the point on the curve.
        """
    def SegmentBeginning(self) -> bool: 
        """
        Returns the flag that the point is the beginning of a segment.
        """
    def SegmentEnd(self) -> bool: 
        """
        Returns the flag that the point is the end of a segment.
        """
    def SetIndex(self,Index : int) -> None: 
        """
        Sets the index of the supporting curve.
        """
    def SetIntersectionType(self,Type : HatchGen_IntersectionType) -> None: 
        """
        Sets the intersection type at this point.

        Sets the intersection type at this point.
        """
    def SetParameter(self,Parameter : float) -> None: 
        """
        Sets the parameter on the curve.
        """
    def SetPosition(self,Position : OCP.TopAbs.TopAbs_Orientation) -> None: 
        """
        Sets the position of the point on the curve.
        """
    def SetSegmentBeginning(self,State : bool=True) -> None: 
        """
        Sets the flag that the point is the beginning of a segment.
        """
    def SetSegmentEnd(self,State : bool=True) -> None: 
        """
        Sets the flag that the point is the end of a segment.
        """
    def SetStateAfter(self,State : OCP.TopAbs.TopAbs_State) -> None: 
        """
        Sets the transition state after the intersection.
        """
    def SetStateBefore(self,State : OCP.TopAbs.TopAbs_State) -> None: 
        """
        Sets the transition state before the intersection.
        """
    def StateAfter(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the transition state after of the intersection.
        """
    def StateBefore(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the transition state before the intersection.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Point : OCP.IntRes2d.IntRes2d_IntersectionPoint) -> None: ...
    pass
class HatchGen_PointOnHatching(HatchGen_IntersectionPoint):
    def AddPoint(self,Point : HatchGen_PointOnElement,Confusion : float) -> None: 
        """
        Adds a point on element to the point.
        """
    def ClrPoints(self) -> None: 
        """
        Removes all the points on element of the point.
        """
    def Dump(self,Index : int=0) -> None: 
        """
        Dump of the point.
        """
    def Index(self) -> int: 
        """
        Returns the index of the supporting curve.
        """
    def IsEqual(self,Point : HatchGen_PointOnHatching,Confusion : float) -> bool: 
        """
        Tests if the point is equal to an other. A point on hatching P1 is said to be equal to an other P2 if : | P2.myParam - P1.myParam | <= Confusion
        """
    def IsGreater(self,Point : HatchGen_PointOnHatching,Confusion : float) -> bool: 
        """
        Tests if the point is greater than an other. A point on hatching P1 is said to be greater than an other P2 if : P1.myParam - P2.myParam > Confusion
        """
    def IsLower(self,Point : HatchGen_PointOnHatching,Confusion : float) -> bool: 
        """
        Tests if the point is lower than an other. A point on hatching P1 is said to be lower than an other P2 if : P2.myParam - P1.myParam > Confusion
        """
    def NbPoints(self) -> int: 
        """
        Returns the number of elements intersecting the hatching at this point.
        """
    def Parameter(self) -> float: 
        """
        Returns the parameter on the curve.
        """
    def Point(self,Index : int) -> HatchGen_PointOnElement: 
        """
        Returns the Index-th point on element of the point. The exception OutOfRange is raised if Index > NbPoints.
        """
    def Position(self) -> OCP.TopAbs.TopAbs_Orientation: 
        """
        Returns the position of the point on the curve.
        """
    def RemPoint(self,Index : int) -> None: 
        """
        Removes the Index-th point on element of the point. The exception OutOfRange is raised if Index > NbPoints.
        """
    def SegmentBeginning(self) -> bool: 
        """
        Returns the flag that the point is the beginning of a segment.
        """
    def SegmentEnd(self) -> bool: 
        """
        Returns the flag that the point is the end of a segment.
        """
    def SetIndex(self,Index : int) -> None: 
        """
        Sets the index of the supporting curve.
        """
    def SetParameter(self,Parameter : float) -> None: 
        """
        Sets the parameter on the curve.
        """
    def SetPosition(self,Position : OCP.TopAbs.TopAbs_Orientation) -> None: 
        """
        Sets the position of the point on the curve.
        """
    def SetSegmentBeginning(self,State : bool=True) -> None: 
        """
        Sets the flag that the point is the beginning of a segment.
        """
    def SetSegmentEnd(self,State : bool=True) -> None: 
        """
        Sets the flag that the point is the end of a segment.
        """
    def SetStateAfter(self,State : OCP.TopAbs.TopAbs_State) -> None: 
        """
        Sets the transition state after the intersection.
        """
    def SetStateBefore(self,State : OCP.TopAbs.TopAbs_State) -> None: 
        """
        Sets the transition state before the intersection.
        """
    def StateAfter(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the transition state after of the intersection.
        """
    def StateBefore(self) -> OCP.TopAbs.TopAbs_State: 
        """
        Returns the transition state before the intersection.
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,Point : OCP.IntRes2d.IntRes2d_IntersectionPoint) -> None: ...
    pass
class HatchGen_PointsOnElement(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : HatchGen_PointOnElement) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : HatchGen_PointsOnElement) -> None: ...
    def Assign(self,theOther : HatchGen_PointsOnElement) -> HatchGen_PointsOnElement: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> HatchGen_PointOnElement: 
        """
        First item access
        """
    def ChangeLast(self) -> HatchGen_PointOnElement: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> HatchGen_PointOnElement: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> HatchGen_PointOnElement: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : HatchGen_PointsOnElement) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : HatchGen_PointOnElement) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : HatchGen_PointOnElement) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : HatchGen_PointsOnElement) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> HatchGen_PointOnElement: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : HatchGen_PointOnElement) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : HatchGen_PointsOnElement) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : HatchGen_PointOnElement) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : HatchGen_PointsOnElement) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> HatchGen_PointOnElement: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HatchGen_PointOnElement: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : HatchGen_PointsOnElement) -> None: ...
    def __iter__(self) -> Iterator[HatchGen_PointOnElement]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
class HatchGen_PointsOnHatching(OCP.NCollection.NCollection_BaseSequence):
    """
    Purpose: Definition of a sequence of elements indexed by an Integer in range of 1..n
    """
    def Allocator(self) -> OCP.NCollection.NCollection_BaseAllocator: 
        """
        Returns attached allocator
        """
    @overload
    def Append(self,theItem : HatchGen_PointOnHatching) -> None: 
        """
        Append one item

        Append another sequence (making it empty)
        """
    @overload
    def Append(self,theSeq : HatchGen_PointsOnHatching) -> None: ...
    def Assign(self,theOther : HatchGen_PointsOnHatching) -> HatchGen_PointsOnHatching: 
        """
        Replace this sequence by the items of theOther. This method does not change the internal allocator.
        """
    def ChangeFirst(self) -> HatchGen_PointOnHatching: 
        """
        First item access
        """
    def ChangeLast(self) -> HatchGen_PointOnHatching: 
        """
        Last item access
        """
    def ChangeValue(self,theIndex : int) -> HatchGen_PointOnHatching: 
        """
        Variable item access by theIndex
        """
    def Clear(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator=None) -> None: 
        """
        Clear the items out, take a new allocator if non null
        """
    def Exchange(self,I : int,J : int) -> None: 
        """
        Exchange two members
        """
    def First(self) -> HatchGen_PointOnHatching: 
        """
        First item access
        """
    @overload
    def InsertAfter(self,theIndex : int,theSeq : HatchGen_PointsOnHatching) -> None: 
        """
        InsertAfter theIndex another sequence (making it empty)

        InsertAfter theIndex theItem
        """
    @overload
    def InsertAfter(self,theIndex : int,theItem : HatchGen_PointOnHatching) -> None: ...
    @overload
    def InsertBefore(self,theIndex : int,theItem : HatchGen_PointOnHatching) -> None: 
        """
        InsertBefore theIndex theItem

        InsertBefore theIndex another sequence (making it empty)
        """
    @overload
    def InsertBefore(self,theIndex : int,theSeq : HatchGen_PointsOnHatching) -> None: ...
    def IsEmpty(self) -> bool: 
        """
        Empty query
        """
    def Last(self) -> HatchGen_PointOnHatching: 
        """
        Last item access
        """
    def Length(self) -> int: 
        """
        Number of items
        """
    def Lower(self) -> int: 
        """
        Method for consistency with other collections.
        """
    @overload
    def Prepend(self,theItem : HatchGen_PointOnHatching) -> None: 
        """
        Prepend one item

        Prepend another sequence (making it empty)
        """
    @overload
    def Prepend(self,theSeq : HatchGen_PointsOnHatching) -> None: ...
    @overload
    def Remove(self,theIndex : int) -> None: 
        """
        Remove one item

        Remove range of items
        """
    @overload
    def Remove(self,theFromIndex : int,theToIndex : int) -> None: ...
    def Reverse(self) -> None: 
        """
        Reverse sequence
        """
    def SetValue(self,theIndex : int,theItem : HatchGen_PointOnHatching) -> None: 
        """
        Set item value by theIndex
        """
    def Size(self) -> int: 
        """
        Number of items
        """
    def Split(self,theIndex : int,theSeq : HatchGen_PointsOnHatching) -> None: 
        """
        Split in two sequences
        """
    def Upper(self) -> int: 
        """
        Method for consistency with other collections.
        """
    def Value(self,theIndex : int) -> HatchGen_PointOnHatching: 
        """
        Constant item access by theIndex
        """
    def __bool__(self) -> bool: ...
    def __call__(self,theIndex : int) -> HatchGen_PointOnHatching: 
        """
        Constant operator()

        Variable operator()
        """
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self,theAllocator : OCP.NCollection.NCollection_BaseAllocator) -> None: ...
    @overload
    def __init__(self,theOther : HatchGen_PointsOnHatching) -> None: ...
    def __iter__(self) -> Iterator[HatchGen_PointOnHatching]: ...
    def __len__(self) -> int: ...
    @staticmethod
    def delNode_s(theNode : NCollection_SeqNode,theAl : OCP.NCollection.NCollection_BaseAllocator) -> None: 
        """
        Static deleter to be passed to BaseSequence
        """
    pass
HatchGen_IncoherentParity: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_IncoherentParity: 3>
HatchGen_IncompatibleStates: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_IncompatibleStates: 4>
HatchGen_NoProblem: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_NoProblem: 0>
HatchGen_TANGENT: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_TANGENT: 2>
HatchGen_TOUCH: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_TOUCH: 1>
HatchGen_TRUE: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_TRUE: 0>
HatchGen_TransitionFailure: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_TransitionFailure: 2>
HatchGen_TrimFailure: OCP.HatchGen.HatchGen_ErrorStatus # value = <HatchGen_ErrorStatus.HatchGen_TrimFailure: 1>
HatchGen_UNDETERMINED: OCP.HatchGen.HatchGen_IntersectionType # value = <HatchGen_IntersectionType.HatchGen_UNDETERMINED: 3>



import OCP.ElCLib
from typing import *
from typing import Iterable as iterable
from typing import Iterator as iterator
from numpy import float64
_Shape = Tuple[int, ...]
import OCP.gp
__all__  = [
"ElCLib"
]
class ElCLib():
    """
    Provides functions for basic geometric computations on elementary curves such as conics and lines in 2D and 3D space. This includes: - calculation of a point or derived vector on a 2D or 3D curve where: - the curve is provided by the gp package, or defined in reference form (as in the gp package), and - the point is defined by a parameter, - evaluation of the parameter corresponding to a point on a 2D or 3D curve from gp, - various elementary computations which allow you to position parameterized values within the period of a curve. Notes: - ElCLib stands for Elementary Curves Library. - If the curves provided by the gp package are not explicitly parameterized, they still have an implicit parameterization, analogous to that which they infer for the equivalent Geom or Geom2d curves.
    """
    @staticmethod
    def AdjustPeriodic_s(UFirst : float,ULast : float,Precision : float) -> tuple[float, float]: 
        """
        Adjust U1 and U2 in the parametric range UFirst Ulast of a periodic curve, where ULast - UFirst is its period. To do this, this function: - sets U1 in the range [ UFirst, ULast ] by adding/removing the period to/from the value U1, then - sets U2 in the range [ U1, U1 + period ] by adding/removing the period to/from the value U2. Precision is used to test the equalities.
        """
    @staticmethod
    @overload
    def CircleD1_s(U : float,Pos : OCP.gp.gp_Ax2,Radius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def CircleD1_s(U : float,Pos : OCP.gp.gp_Ax22d,Radius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def CircleD2_s(U : float,Pos : OCP.gp.gp_Ax2,Radius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def CircleD2_s(U : float,Pos : OCP.gp.gp_Ax22d,Radius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def CircleD3_s(U : float,Pos : OCP.gp.gp_Ax2,Radius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def CircleD3_s(U : float,Pos : OCP.gp.gp_Ax22d,Radius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d,V3 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def CircleDN_s(U : float,Pos : OCP.gp.gp_Ax2,Radius : float,N : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def CircleDN_s(U : float,Pos : OCP.gp.gp_Ax22d,Radius : float,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def CircleParameter_s(Pos : OCP.gp.gp_Ax2,P : OCP.gp.gp_Pnt) -> float: 
        """
        Pos is the Axis of the Circle parametrization In the local coordinate system of the circle X (U) = Radius * Cos (U) Y (U) = Radius * Sin (U)
        """
    @staticmethod
    @overload
    def CircleParameter_s(Pos : OCP.gp.gp_Ax22d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def CircleValue_s(U : float,Pos : OCP.gp.gp_Ax2,Radius : float) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def CircleValue_s(U : float,Pos : OCP.gp.gp_Ax22d,Radius : float) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def D1_s(U : float,L : OCP.gp.gp_Lin,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: 
        """
        For elementary curves (lines, circles and conics) from the gp package, computes: - the point P of parameter U, and - the first derivative vector V1 at this point. The results P and V1 are either: - a gp_Pnt point and a gp_Vec vector, for a curve in 3D space, or - a gp_Pnt2d point and a gp_Vec2d vector, for a curve in 2D space.
        """
    @staticmethod
    @overload
    def D1_s(U : float,C : OCP.gp.gp_Circ,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,E : OCP.gp.gp_Elips,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,H : OCP.gp.gp_Hypr,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,Prb : OCP.gp.gp_Parab,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,L : OCP.gp.gp_Lin2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,C : OCP.gp.gp_Circ2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,E : OCP.gp.gp_Elips2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,H : OCP.gp.gp_Hypr2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D1_s(U : float,Prb : OCP.gp.gp_Parab2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D2_s(U : float,C : OCP.gp.gp_Circ,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: 
        """
        For elementary curves (circles and conics) from the gp package, computes: - the point P of parameter U, and - the first and second derivative vectors V1 and V2 at this point. The results, P, V1 and V2, are either: - a gp_Pnt point and two gp_Vec vectors, for a curve in 3D space, or - a gp_Pnt2d point and two gp_Vec2d vectors, for a curve in 2D space.
        """
    @staticmethod
    @overload
    def D2_s(U : float,E : OCP.gp.gp_Elips,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D2_s(U : float,H : OCP.gp.gp_Hypr,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D2_s(U : float,Prb : OCP.gp.gp_Parab,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D2_s(U : float,C : OCP.gp.gp_Circ2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D2_s(U : float,E : OCP.gp.gp_Elips2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D2_s(U : float,H : OCP.gp.gp_Hypr2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D2_s(U : float,Prb : OCP.gp.gp_Parab2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D3_s(U : float,C : OCP.gp.gp_Circ,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: 
        """
        For elementary curves (circles, ellipses and hyperbolae) from the gp package, computes: - the point P of parameter U, and - the first, second and third derivative vectors V1, V2 and V3 at this point. The results, P, V1, V2 and V3, are either: - a gp_Pnt point and three gp_Vec vectors, for a curve in 3D space, or - a gp_Pnt2d point and three gp_Vec2d vectors, for a curve in 2D space.

        In the following functions N is the order of derivation and should be greater than 0
        """
    @staticmethod
    @overload
    def D3_s(U : float,E : OCP.gp.gp_Elips,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D3_s(U : float,H : OCP.gp.gp_Hypr,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def D3_s(U : float,C : OCP.gp.gp_Circ2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d,V3 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D3_s(U : float,E : OCP.gp.gp_Elips2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d,V3 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def D3_s(U : float,H : OCP.gp.gp_Hypr2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d,V3 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def DN_s(U : float,L : OCP.gp.gp_Lin,N : int) -> OCP.gp.gp_Vec: 
        """
        For elementary curves (lines, circles and conics) from the gp package, computes the vector corresponding to the Nth derivative at the point of parameter U. The result is either: - a gp_Vec vector for a curve in 3D space, or - a gp_Vec2d vector for a curve in 2D space. In the following functions N is the order of derivation and should be greater than 0
        """
    @staticmethod
    @overload
    def DN_s(U : float,C : OCP.gp.gp_Circ,N : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def DN_s(U : float,E : OCP.gp.gp_Elips,N : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def DN_s(U : float,H : OCP.gp.gp_Hypr,N : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def DN_s(U : float,Prb : OCP.gp.gp_Parab,N : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def DN_s(U : float,L : OCP.gp.gp_Lin2d,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def DN_s(U : float,C : OCP.gp.gp_Circ2d,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def DN_s(U : float,E : OCP.gp.gp_Elips2d,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def DN_s(U : float,H : OCP.gp.gp_Hypr2d,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def DN_s(U : float,Prb : OCP.gp.gp_Parab2d,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def EllipseD1_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def EllipseD1_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def EllipseD2_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def EllipseD2_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def EllipseD3_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def EllipseD3_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d,V3 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def EllipseDN_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,N : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def EllipseDN_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def EllipseParameter_s(Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt) -> float: 
        """
        Pos is the Axis of the Ellipse parametrization In the local coordinate system of the Ellipse X (U) = MajorRadius * Cos (U) Y (U) = MinorRadius * Sin (U)
        """
    @staticmethod
    @overload
    def EllipseParameter_s(Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def EllipseValue_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def EllipseValue_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def HyperbolaD1_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def HyperbolaD1_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def HyperbolaD2_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def HyperbolaD2_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def HyperbolaD3_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec,V3 : OCP.gp.gp_Vec) -> None: 
        """
        In the following functions N is the order of derivation and should be greater than 0
        """
    @staticmethod
    @overload
    def HyperbolaD3_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d,V3 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def HyperbolaDN_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,N : int) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def HyperbolaDN_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def HyperbolaParameter_s(Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt) -> float: 
        """
        Pos is the Axis of the Hyperbola parametrization In the local coordinate system of the Hyperbola X (U) = MajorRadius * Ch (U) Y (U) = MinorRadius * Sh (U)
        """
    @staticmethod
    @overload
    def HyperbolaParameter_s(Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def HyperbolaValue_s(U : float,Pos : OCP.gp.gp_Ax2,MajorRadius : float,MinorRadius : float) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def HyperbolaValue_s(U : float,Pos : OCP.gp.gp_Ax22d,MajorRadius : float,MinorRadius : float) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    def InPeriod_s(U : float,UFirst : float,ULast : float) -> float: 
        """
        Return a value in the range <UFirst, ULast> by adding or removing the period <ULast - UFirst> to <U>. ATTENTION!!! It is expected but not checked that (ULast > UFirst)
        """
    @staticmethod
    @overload
    def LineD1_s(U : float,Pos : OCP.gp.gp_Ax1,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def LineD1_s(U : float,Pos : OCP.gp.gp_Ax2d,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def LineDN_s(U : float,Pos : OCP.gp.gp_Ax1,N : int) -> OCP.gp.gp_Vec: 
        """
        In the following functions N is the order of derivation and should be greater than 0
        """
    @staticmethod
    @overload
    def LineDN_s(U : float,Pos : OCP.gp.gp_Ax2d,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def LineParameter_s(Pos : OCP.gp.gp_Ax1,P : OCP.gp.gp_Pnt) -> float: 
        """
        parametrization P (U) = L.Location() + U * L.Direction()
        """
    @staticmethod
    @overload
    def LineParameter_s(Pos : OCP.gp.gp_Ax2d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def LineValue_s(U : float,Pos : OCP.gp.gp_Ax1) -> OCP.gp.gp_Pnt: 
        """
        Curve evaluation The following basis functions compute the derivatives on elementary curves defined by their geometric characteristics. These functions can be called without constructing a conic from package gp. They are called by the previous functions. Example : A circle is defined by its position and its radius.
        """
    @staticmethod
    @overload
    def LineValue_s(U : float,Pos : OCP.gp.gp_Ax2d) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def ParabolaD1_s(U : float,Pos : OCP.gp.gp_Ax2,Focal : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def ParabolaD1_s(U : float,Pos : OCP.gp.gp_Ax22d,Focal : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def ParabolaD2_s(U : float,Pos : OCP.gp.gp_Ax2,Focal : float,P : OCP.gp.gp_Pnt,V1 : OCP.gp.gp_Vec,V2 : OCP.gp.gp_Vec) -> None: ...
    @staticmethod
    @overload
    def ParabolaD2_s(U : float,Pos : OCP.gp.gp_Ax22d,Focal : float,P : OCP.gp.gp_Pnt2d,V1 : OCP.gp.gp_Vec2d,V2 : OCP.gp.gp_Vec2d) -> None: ...
    @staticmethod
    @overload
    def ParabolaDN_s(U : float,Pos : OCP.gp.gp_Ax2,Focal : float,N : int) -> OCP.gp.gp_Vec: 
        """
        The following functions compute the parametric value corresponding to a given point on a elementary curve. The point should be on the curve.
        """
    @staticmethod
    @overload
    def ParabolaDN_s(U : float,Pos : OCP.gp.gp_Ax22d,Focal : float,N : int) -> OCP.gp.gp_Vec2d: ...
    @staticmethod
    @overload
    def ParabolaParameter_s(Pos : OCP.gp.gp_Ax2,P : OCP.gp.gp_Pnt) -> float: 
        """
        Pos is the mirror axis of the parabola parametrization In the local coordinate system of the parabola Y**2 = (2*P) * X where P is the distance between the focus and the directrix. The following functions build a 3d curve from a 2d curve at a given position defined with an Ax2.
        """
    @staticmethod
    @overload
    def ParabolaParameter_s(Pos : OCP.gp.gp_Ax22d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def ParabolaValue_s(U : float,Pos : OCP.gp.gp_Ax2,Focal : float) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def ParabolaValue_s(U : float,Pos : OCP.gp.gp_Ax22d,Focal : float) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def Parameter_s(L : OCP.gp.gp_Lin,P : OCP.gp.gp_Pnt) -> float: 
        """
        Computes the parameter value of the point P on the given curve. Note: In its local coordinate system, the parametric equation of the curve is given by the following: - for the line L: P(U) = Po + U*Vo where Po is the origin and Vo the unit vector of its positioning axis. - for the circle C: X(U) = Radius*Cos(U), Y(U) = Radius*Sin(U) - for the ellipse E: X(U) = MajorRadius*Cos(U). Y(U) = MinorRadius*Sin(U) - for the hyperbola H: X(U) = MajorRadius*Ch(U), Y(U) = MinorRadius*Sh(U) - for the parabola Prb: X(U) = U**2 / (2*p) Y(U) = U where p is the distance between the focus and the directrix. Warning The point P must be on the curve. These functions are not protected, however, and if point P is not on the curve, an exception may be raised.

        parametrization P (U) = L.Location() + U * L.Direction()

        parametrization In the local coordinate system of the circle X (U) = Radius * Cos (U) Y (U) = Radius * Sin (U)

        parametrization In the local coordinate system of the Ellipse X (U) = MajorRadius * Cos (U) Y (U) = MinorRadius * Sin (U)

        parametrization In the local coordinate system of the Hyperbola X (U) = MajorRadius * Ch (U) Y (U) = MinorRadius * Sh (U)

        parametrization In the local coordinate system of the parabola Y**2 = (2*P) * X where P is the distance between the focus and the directrix.
        """
    @staticmethod
    @overload
    def Parameter_s(L : OCP.gp.gp_Lin2d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(C : OCP.gp.gp_Circ,P : OCP.gp.gp_Pnt) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(C : OCP.gp.gp_Circ2d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(E : OCP.gp.gp_Elips,P : OCP.gp.gp_Pnt) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(E : OCP.gp.gp_Elips2d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(H : OCP.gp.gp_Hypr,P : OCP.gp.gp_Pnt) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(H : OCP.gp.gp_Hypr2d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(Prb : OCP.gp.gp_Parab,P : OCP.gp.gp_Pnt) -> float: ...
    @staticmethod
    @overload
    def Parameter_s(Prb : OCP.gp.gp_Parab2d,P : OCP.gp.gp_Pnt2d) -> float: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,P : OCP.gp.gp_Pnt2d) -> OCP.gp.gp_Pnt: 
        """
        These functions build a 3D geometric entity from a 2D geometric entity. The "X Axis" and the "Y Axis" of the global coordinate system (i.e. 2D space) are lined up respectively with the "X Axis" and "Y Axis" of the 3D coordinate system, Pos.
        """
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,V : OCP.gp.gp_Vec2d) -> OCP.gp.gp_Vec: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,V : OCP.gp.gp_Dir2d) -> OCP.gp.gp_Dir: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,A : OCP.gp.gp_Ax2d) -> OCP.gp.gp_Ax1: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,A : OCP.gp.gp_Ax22d) -> OCP.gp.gp_Ax2: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,L : OCP.gp.gp_Lin2d) -> OCP.gp.gp_Lin: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,C : OCP.gp.gp_Circ2d) -> OCP.gp.gp_Circ: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,E : OCP.gp.gp_Elips2d) -> OCP.gp.gp_Elips: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,H : OCP.gp.gp_Hypr2d) -> OCP.gp.gp_Hypr: ...
    @staticmethod
    @overload
    def To3d_s(Pos : OCP.gp.gp_Ax2,Prb : OCP.gp.gp_Parab2d) -> OCP.gp.gp_Parab: ...
    @staticmethod
    @overload
    def Value_s(U : float,L : OCP.gp.gp_Lin) -> OCP.gp.gp_Pnt: 
        """
        For elementary curves (lines, circles and conics) from the gp package, computes the point of parameter U. The result is either: - a gp_Pnt point for a curve in 3D space, or - a gp_Pnt2d point for a curve in 2D space.
        """
    @staticmethod
    @overload
    def Value_s(U : float,C : OCP.gp.gp_Circ) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def Value_s(U : float,E : OCP.gp.gp_Elips) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def Value_s(U : float,H : OCP.gp.gp_Hypr) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def Value_s(U : float,Prb : OCP.gp.gp_Parab) -> OCP.gp.gp_Pnt: ...
    @staticmethod
    @overload
    def Value_s(U : float,L : OCP.gp.gp_Lin2d) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def Value_s(U : float,C : OCP.gp.gp_Circ2d) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def Value_s(U : float,E : OCP.gp.gp_Elips2d) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def Value_s(U : float,H : OCP.gp.gp_Hypr2d) -> OCP.gp.gp_Pnt2d: ...
    @staticmethod
    @overload
    def Value_s(U : float,Prb : OCP.gp.gp_Parab2d) -> OCP.gp.gp_Pnt2d: ...
    def __init__(self) -> None: ...
    pass
